==> gitlify-0.0.1.tgz: package/lib/cli.js <==
#!/usr/bin/env node
'use strict';

var axios = require('axios');
require('dotenv').config();

process.argv && console.log('looking for environmental variables in', process.cwd());

var _process$argv = process.argv,
    _process$argv$ = _process$argv[2],
    argvBranchName = _process$argv$ === undefined ? '' : _process$argv$,
    _process$argv$2 = _process$argv[3],
    argvWebhookUrl = _process$argv$2 === undefined ? '' : _process$argv$2;
var _process$env = process.env,
    GITHUB_USER = _process$env.GITHUB_USER,
    NETLIFY_WEBHOOK = _process$env.NETLIFY_WEBHOOK;


var gitlifyCLI = function gitlifyCLI() {
    var branchName = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : argvBranchName || '';
    var webhookId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : NETLIFY_WEBHOOK || argvWebhookUrl || '';
    var developer = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : GITHUB_USER || 'anonymous';
    var appMode = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : process.argv ? 'CLI' : 'Plugin';
    return branchName && webhookId && !['', 'anonymous'].includes(developer) ? axios('https://api.github.com/users/' + developer).then(function () {
        return axios.post('https://api.netlify.com/build_hooks/' + webhookId + '?trigger_branch=' + branchName + '&trigger_title=triggered+manually+by+' + developer + '+using+Gitlify' + appMode).then(function (_ref) {
            var data = _ref.data,
                status = _ref.status;
            return console.log('deploy command sent', status, data);
        }).catch(function (error) {
            return console.log('something went wrong', error);
        });
    }).catch(function () {
        return console.log('user name not found:', developer);
    }) : console.log('Error: You need to give me a valid branch name, webhook url and username.', branchName, webhookId, developer);
};

exports.module = gitlifyCLI;

process.argv && gitlifyCLI();

==> gitlify-0.0.2.tgz: package/lib/cli.js <==
#!/usr/bin/env node
'use strict';

var axios = require('axios');
require('dotenv').config();

process.argv && console.log('looking for environmental variables in', process.cwd());

var _process$argv = process.argv,
    _process$argv$ = _process$argv[2],
    argvBranchName = _process$argv$ === undefined ? '' : _process$argv$,
    _process$argv$2 = _process$argv[3],
    argvWebhookUrl = _process$argv$2 === undefined ? '' : _process$argv$2;
var _process$env = process.env,
    GITHUB_TOKEN = _process$env.GITHUB_TOKEN,
    GITHUB_USER = _process$env.GITHUB_USER,
    NETLIFY_WEBHOOK = _process$env.NETLIFY_WEBHOOK;


var gitlifyCLI = function gitlifyCLI() {
    var branchName = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : argvBranchName || '';
    var webhookId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : NETLIFY_WEBHOOK || argvWebhookUrl || '';
    var developer = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : GITHUB_USER || 'anonymous';
    var token = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : GITHUB_TOKEN || '';
    var appMode = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : process.argv ? 'CLI' : 'Plugin';
    return branchName && webhookId && token && !['', 'anonymous'].includes(developer) ? axios('https://api.github.com/users/' + developer, {
        headers: {
            'Authorization': 'Bearer ' + token
        }
    }).then(function () {
        return axios.post('https://api.netlify.com/build_hooks/' + webhookId + '?trigger_branch=' + branchName + '&trigger_title=triggered+manually+by+' + developer + '+using+Gitlify' + appMode).then(function (_ref) {
            var data = _ref.data,
                status = _ref.status;
            return console.log('deploy command sent', status, data);
        }).catch(function (error) {
            return console.log('something went wrong with Netlify', error);
        });
    }).catch(function (error) {
        return console.log('something went wrong with GitHub', error);
    }) : console.log('Error: You need to give me a valid branch name, Netlify webhook URL, GitHub personal access token, and GitHub username.', branchName, webhookId, token, developer);
};

exports.module = gitlifyCLI;

process.argv && gitlifyCLI();
